# geoconformal

Geospatial Conformal Prediction Methods.

## Installation

```bash
pip install geoconformal
```

## Usage

```python
from geoconformal import GeoConformalSpatialRegression
```

## License
MIT License
